============
Installation
============

At the command line::

    $ easy_install dj-2fa-social-auth

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv dj-2fa-social-auth
    $ pip install dj-2fa-social-auth
